pipe_pane: Pipe contents of a pane to a shell command.
Description
Pipe contents of a pane to a shell command.
Usage
pipe_pane(target = NULL, shell_command = NULL, open = FALSE)
Arguments
target
A session, window, or pane.
shell_command
String. System command to be invoked when creating the
session.
open
Logical. Only open a new pipe if no previous pipe exists.